You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by dj...@apache.org on 2006/10/25 22:45:20 UTC

svn commit: r467755 - /db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/nist/NistScripts.java

Author: djd
Date: Wed Oct 25 13:45:18 2006
New Revision: 467755

URL: http://svn.apache.org/viewvc?view=rev&rev=467755
Log:
Add test suite names to NistScripts (which is still under development).

Modified:
    db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/nist/NistScripts.java

Modified: db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/nist/NistScripts.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/nist/NistScripts.java?view=diff&rev=467755&r1=467754&r2=467755
==============================================================================
--- db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/nist/NistScripts.java (original)
+++ db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/nist/NistScripts.java Wed Oct 25 13:45:18 2006
@@ -170,7 +170,7 @@
 	 * Return the suite that runs the NIST SQL scripts.
 	 */
 	public static Test suite() {
-        TestSuite suite = new TestSuite();
+        TestSuite suite = new TestSuite("NIST");
         
         String suiteUser = null;
         TestSuite userSuite = null; 
@@ -189,7 +189,7 @@
             
             // Add the new user suite with the change user decorator to
             // the main suite but continue to add tests to the user suite.
-            userSuite = new TestSuite(); 
+            userSuite = new TestSuite("NIST user="+testUser); 
             String password = testUser.concat("PWD");
             suite.addTest(
                     TestConfiguration.changeUserDecorator(userSuite, testUser, password));
@@ -202,7 +202,7 @@
     }
     
 	/*
 	 * A single JUnit test that runs a single language SQL script.
 	 */
 	private NistScripts(String nistScript){
 		super(nistScript);
@@ -202,7 +202,7 @@
     
 	/*
-	 * A single JUnit test that runs a single language SQL script.
+	 * A single JUnit test that runs a single Nist SQL script.
 	 */
 	private NistScripts(String nistScript){